@@ -160,6 +160,7 @@ class Bump:
         build_metadata = self.arguments["build_metadata"]
         increment_mode: str = self.arguments["increment_mode"]
         get_next: bool = self.arguments["get_next"]
+        allow_no_commit: bool | None = self.arguments["allow_no_commit"]
 
         if manual_version:
             if increment:
@@ -250,9 +251,13 @@ class Bump:
 
                 # No commits, there is no need to create an empty tag.
                 # Unless we previously had a prerelease.
-                if not commits and not current_version.is_prerelease:
+                if (
+                    not commits
+                    and not current_version.is_prerelease
+                    and not allow_no_commit
+                ):
                     raise NoCommitsFoundError(
-                        "[NO_COMMITS_FOUND]\n" "No new commits found."
+                        "[NO_COMMITS_FOUND]\nNo new commits found."
                     )
 
                 increment = self.find_increment(commits)
@@ -266,6 +271,10 @@ class Bump:
                     "To avoid this error, manually specify the type of increment with `--increment`"
                 )
 
+            # we create an empty PATCH increment for empty tag
+            if increment is None and allow_no_commit:
+                increment = "PATCH"
+
             new_version = current_version.bump(
                 increment,
                 prerelease=prerelease,
@@ -296,7 +305,7 @@ class Bump:
             raise GetNextExit()
 
         # Report found information
-        information = f"{message}\n" f"tag to create: {new_tag_version}\n"
+        information = f"{message}\ntag to create: {new_tag_version}\n"
         if increment:
             information += f"increment detected: {increment}\n"
 
@@ -310,8 +319,7 @@ class Bump:
 
         if increment is None and new_tag_version == current_tag_version:
             raise NoneIncrementExit(
-                "[NO_COMMITS_TO_BUMP]\n"
-                "The commits found are not eligible to be bumped"
+                "[NO_COMMITS_TO_BUMP]\nThe commits found are not eligible to be bumped"
             )
 
         files: list[str] = []
