@@ -6,12 +6,13 @@ from pathlib import Path
 from tomlkit import exceptions, parse, table
 
 from commitizen.exceptions import InvalidConfigurationError
+
 from .base_config import BaseConfig
 
 
 class TomlConfig(BaseConfig):
     def __init__(self, *, data: bytes | str, path: Path | str):
-        super(TomlConfig, self).__init__()
+        super().__init__()
         self.is_empty_config = False
         self.add_path(path)
         self._parse_setting(data)
