@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+import os
+
 from commitizen import cmd, out
 from commitizen.exceptions import RunHookError
 
@@ -25,7 +27,7 @@ def run(hooks, _env_prefix="CZ_", **env):
 def _format_env(prefix: str, env: dict[str, str]) -> dict[str, str]:
     """_format_env() prefixes all given environment variables with the given
     prefix so it can be passed directly to cmd.run()."""
-    penv = dict()
+    penv = dict(os.environ)
     for name, value in env.items():
         name = prefix + name.upper()
         value = str(value) if value is not None else ""
